==> lxqt-panel_1.1.0.orig.tar.xz: lxqt-panel-1.1.0/plugin-cpuload/translations/cpuload_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation>الحمل على المعالج  %1٪</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>إعدادات الحمل على المعالج</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>عام</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>اعرض النص</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>فترة التحديث:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>ثا</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>اتجاه الشريط:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>عرض الشريط:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="64"/>
        <source>Bottom up</source>
        <translation>أسفل لأعلى</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="65"/>
        <source>Top down</source>
        <translation>أعلى لأسفل</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="66"/>
        <source>Left to right</source>
        <translation>يسار إلى يمين</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="67"/>
        <source>Right to left</source>
        <translation>يمين إلى يسار</translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.4.0.orig.tar.xz: lxqt-panel-1.4.0/plugin-cpuload/translations/cpuload_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation>الحمل على المعالج %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>إعدادات الحمل على المعالج</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>عام</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>اعرض النص</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>فترة التحديث:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>ثا</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>اتجاه الشريط:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>عرض الشريط:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="64"/>
        <source>Bottom up</source>
        <translation>أسفل لأعلى</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="65"/>
        <source>Top down</source>
        <translation>أعلى لأسفل</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="66"/>
        <source>Left to right</source>
        <translation>يسار إلى يمين</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="67"/>
        <source>Right to left</source>
        <translation>يمين إلى يسار</translation>
    </message>
</context>
</TS>
